# Changelog
All notable changes to this project will be documented in this file.

## [0.4.1] - 2019-09-09
### Added
- Support new boards:
  - Alchitry-Cu (#179)
  - Fomu (#182)
- Add project structure to the docs (#177)

## Fixed
- Pytest "offline" option
- Production iCEBreaker USB strings (#181)

## [0.4.0] - 2018-11-07
### Added
- New command: raw.
- Support new boards:
  - UPDuino v1.0
  - UPDuino v2.0
  - iCEBreaker
  - iCEBreaker bitsy
  - FPGA 101 Workshop Badge Board
  - iCE40 UltraPlus Breakout Board

## [0.3.6] - 2018-09-16
### Changed
- Improve TinyFPGA BX integration

## [0.3.4] - 2018-08-17
### Added
- New command: lint.
- Support new boards:
  - TinyFPGA BX
  - iCEblink40-HX1K

## [0.3.3] - 2018-05-10
### Added
- Support new boards:
  - Alhambra II

## [0.3.0] - 2018-02-01
### Added
- Support new boards:
  - TinyFPGA B2
  - BlackIce
  - BlackIce II

### Changed
- Update "apio drivers" options: ftdi, serial.

## [0.2.0] - 2016-12-01
### Added
- New commands: verify, boards, config, drivers, upgrade.
- Support new boards:
  - Nandland Go board
  - icoBOARD 1.0
  - Kéfir I iCE40-HX4K
  - iCE40-HX8K Breakout Board
  - CAT Board

### Removed
- Delete command: debug.

## [0.1.0] - 2016-04-14  
### Added
- New commands: examples, init, system.

## [0.0.4] - 2016-02-24  
### Added
- New commands: build, clean, debug, install, sim, time, uninstall, upload.
- Support new boards:
  - iCEstick Evaluation Kit
  - IceZUM Alhambra.
